@@ -16,9 +16,9 @@ except ImportError:  # Python 3
 import time
 import yaml
 # mine
-import utils
-import preprocessing
-import HandwrittenData
+from . import utils
+from . import preprocessing
+from . import HandwrittenData
 
 sys.modules['hwrt.HandwrittenData'] = HandwrittenData
 sys.modules['HandwrittenData'] = HandwrittenData
